pysmug.smugmug

Package pysmug :: Module smugmug |
[hide private]
[frames] | no frames]

# Module smugmug

source code

Version: 0.3

Classes | [hide private]
| SmugMugException Representation of a SmugMug exception.
| HTTPException An exception thrown during http(s) communication.
| SmugBase Abstract functionality for SmugMug API clients.
| SmugMug Serial version of a SmugMug client.
| SmugBatch Batching version of a SmugMug client.

Variables | [hide private]
| _userAgent = ``'``pysmug(0.3)``'``
| _curlinfo = ``(``(``'``total-time``'``,` 3145731`)``,` `(``'``upload-speed``'``,` 3145738`...``

Variables Details | [hide private]

  ### _curlinfo Value:
      (('total-time', 3145731),
       ('upload-speed', 3145738),
       ('download-speed', 3145737))